"use strict";
exports.__esModule = true;
require("jasmine");
var PromptValidator_1 = require("./PromptValidator");
var promptValidator = new PromptValidator_1["default"]();
describe("back", function () {
    var result;
    Run("none", 0, function (spies) { return null; });
    Run("text", 1, function (spies) { return ({
        key: "text",
        value: {
            minimumLength: 10,
            maximumLength: 25,
            onEntry: spies[0]
        }
    }); });
    Run("password", 1, function (spies) { return ({
        key: "password",
        value: {
            minimumLength: 10,
            maximumLength: 25,
            onEntry: spies[0]
        }
    }); });
    Run("number", 1, function (spies) { return ({
        key: "number",
        value: {
            minimum: 5.4,
            maximum: 18.7,
            step: 0.4,
            onEntry: spies[0]
        }
    }); });
    Run("multiple choice", 4, function (spies) { return ({
        key: "multipleChoice",
        value: {
            options: [{
                    label: "Test Option Label A",
                    onSelection: spies[0]
                }, {
                    label: "Test Option Label B",
                    onSelection: spies[1]
                }, {
                    label: "Test Option Label C",
                    onSelection: spies[2]
                }, {
                    label: "Test Option Label D",
                    onSelection: spies[3]
                }]
        }
    }); });
    function Run(description, numberOfSpies, controlFactory) {
        describe(description, function () {
            var spies;
            beforeEach(function () {
                spies = [];
                while (spies.length < numberOfSpies) {
                    spies.push(jasmine.createSpy());
                }
            });
            describe("without back button", function () {
                beforeEach(function () { return result = promptValidator.back({
                    label: "Test Prompt Label",
                    description: "Test Prompt Description",
                    control: controlFactory(spies),
                    onBack: null
                }); });
                it("returns type \"invalidControl\"", function () { return expect(result).toEqual({ type: "invalidControl" }); });
                it("does not execute any methods on the control", function () { return spies.forEach(function (spy) { return expect(spy).not.toHaveBeenCalled(); }); });
            });
            describe("with back button", function () {
                var onBack;
                beforeEach(function () {
                    onBack = jasmine.createSpy();
                    onBack.and.returnValue({ eventContent: "Test Event Content" });
                    result = promptValidator.back({
                        label: "Test Prompt Label",
                        description: "Test Prompt Description",
                        control: controlFactory(spies),
                        onBack: onBack
                    });
                });
                it("generates one event from the back button", function () { return expect(onBack).toHaveBeenCalledTimes(1); });
                it("returns type \"success\" and the event", function () { return expect(result).toEqual({
                    type: "success",
                    event: { eventContent: "Test Event Content" }
                }); });
                it("does not execute any methods on the control", function () { return spies.forEach(function (spy) { return expect(spy).not.toHaveBeenCalled(); }); });
            });
        });
    }
});
describe("text", function () {
    RunIgnoringBackButton("none", 0, function (spies, onBack) { return promptValidator.text(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: null,
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
    });
    describe("text", function () {
        RunIgnoringBackButton("too short", 1, function (spies, onBack) { return promptValidator.text(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
            label: "Test Prompt Label",
            description: "Test Prompt Description",
            control: {
                key: "text",
                value: {
                    minimumLength: 18,
                    maximumLength: 25,
                    onEntry: spies[0]
                }
            },
            onBack: onBack
        }); }, function (spiesFactory, resultFactory) {
            it("returns type \"tooShort\"", function () { return expect(resultFactory()).toEqual({ type: "tooShort" }); });
            it("does not generate an event from text entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
        });
        RunIgnoringBackButton("minimum length", 1, function (spies, onBack) {
            spies[0].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.text(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "text",
                    value: {
                        minimumLength: 17,
                        maximumLength: 25,
                        onEntry: spies[0]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("generates one event from text entry", function () { return expect(spiesFactory()[0]).toHaveBeenCalledTimes(1); });
            it("generates the event using the entered text", function () { return expect(spiesFactory()[0]).toHaveBeenCalledWith("test example text"); });
            it("returns type \"success\" and the event", function () { return expect(resultFactory()).toEqual({
                type: "success",
                event: { eventContent: "Test Event Content" }
            }); });
        });
        RunIgnoringBackButton("maximum length", 1, function (spies, onBack) {
            spies[0].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.text(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "text",
                    value: {
                        minimumLength: 10,
                        maximumLength: 17,
                        onEntry: spies[0]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("generates one event from text entry", function () { return expect(spiesFactory()[0]).toHaveBeenCalledTimes(1); });
            it("generates the event using the entered text", function () { return expect(spiesFactory()[0]).toHaveBeenCalledWith("test example text"); });
            it("returns type \"success\" and the event", function () { return expect(resultFactory()).toEqual({
                type: "success",
                event: { eventContent: "Test Event Content" }
            }); });
        });
        RunIgnoringBackButton("too long", 1, function (spies, onBack) { return promptValidator.text(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
            label: "Test Prompt Label",
            description: "Test Prompt Description",
            control: {
                key: "text",
                value: {
                    minimumLength: 10,
                    maximumLength: 16,
                    onEntry: spies[0]
                }
            },
            onBack: onBack
        }); }, function (spiesFactory, resultFactory) {
            it("returns type \"tooLong\"", function () { return expect(resultFactory()).toEqual({ type: "tooLong" }); });
            it("does not generate an event from text entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
        });
    });
    RunIgnoringBackButton("password", 1, function (spies, onBack) { return promptValidator.text(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "password",
            value: {
                minimumLength: 10,
                maximumLength: 25,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from password entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    RunIgnoringBackButton("number", 1, function (spies, onBack) { return promptValidator.text(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "number",
            value: {
                minimum: 5.4,
                maximum: 18.7,
                step: 0.4,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from number entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    RunIgnoringBackButton("multiple choice", 4, function (spies, onBack) { return promptValidator.text(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "multipleChoice",
            value: {
                options: [{
                        label: "Test Option Label A",
                        onSelection: spies[0]
                    }, {
                        label: "Test Option Label B",
                        onSelection: spies[1]
                    }, {
                        label: "Test Option Label C",
                        onSelection: spies[2]
                    }, {
                        label: "Test Option Label D",
                        onSelection: spies[3]
                    }]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from any option", function () { return spiesFactory().forEach(function (spy) { return expect(spy).not.toHaveBeenCalled(); }); });
    });
});
describe("password", function () {
    RunIgnoringBackButton("none", 0, function (spies, onBack) { return promptValidator.password(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: null,
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
    });
    RunIgnoringBackButton("text", 1, function (spies, onBack) { return promptValidator.password(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "text",
            value: {
                minimumLength: 10,
                maximumLength: 25,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from text entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    describe("password", function () {
        RunIgnoringBackButton("too short", 1, function (spies, onBack) { return promptValidator.password(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
            label: "Test Prompt Label",
            description: "Test Prompt Description",
            control: {
                key: "password",
                value: {
                    minimumLength: 25,
                    maximumLength: 33,
                    onEntry: spies[0]
                }
            },
            onBack: onBack
        }); }, function (spiesFactory, resultFactory) {
            it("returns type \"tooShort\"", function () { return expect(resultFactory()).toEqual({ type: "tooShort" }); });
            it("does not generate an event from password entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
        });
        RunIgnoringBackButton("minimum length", 1, function (spies, onBack) {
            spies[0].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.password(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "password",
                    value: {
                        minimumLength: 24,
                        maximumLength: 33,
                        onEntry: spies[0]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("generates one event from text entry", function () { return expect(spiesFactory()[0]).toHaveBeenCalledTimes(1); });
            it("generates the event using the entered password", function () { return expect(spiesFactory()[0])
                .toHaveBeenCalledWith("tEsT \t \r exaMPLE \n  text"); });
            it("returns type \"success\" and the event", function () { return expect(resultFactory()).toEqual({
                type: "success",
                event: { eventContent: "Test Event Content" }
            }); });
        });
        RunIgnoringBackButton("maximum length", 1, function (spies, onBack) {
            spies[0].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.password(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "password",
                    value: {
                        minimumLength: 10,
                        maximumLength: 24,
                        onEntry: spies[0]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("generates one event from password entry", function () { return expect(spiesFactory()[0]).toHaveBeenCalledTimes(1); });
            it("generates the event using the entered password", function () { return expect(spiesFactory()[0])
                .toHaveBeenCalledWith("tEsT \t \r exaMPLE \n  text"); });
            it("returns type \"success\" and the event", function () { return expect(resultFactory()).toEqual({
                type: "success",
                event: { eventContent: "Test Event Content" }
            }); });
        });
        RunIgnoringBackButton("too long", 1, function (spies, onBack) { return promptValidator.password(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
            label: "Test Prompt Label",
            description: "Test Prompt Description",
            control: {
                key: "password",
                value: {
                    minimumLength: 10,
                    maximumLength: 23,
                    onEntry: spies[0]
                }
            },
            onBack: onBack
        }); }, function (spiesFactory, resultFactory) {
            it("returns type \"tooLong\"", function () { return expect(resultFactory()).toEqual({ type: "tooLong" }); });
            it("does not generate an event from password entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
        });
    });
    RunIgnoringBackButton("number", 1, function (spies, onBack) { return promptValidator.password(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "number",
            value: {
                minimum: 5.4,
                maximum: 18.7,
                step: 0.4,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from number entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    RunIgnoringBackButton("multiple choice", 4, function (spies, onBack) { return promptValidator.password(" \n \n    \t \r tEsT \t \r exaMPLE \n  text   \t \t \r \n ", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "multipleChoice",
            value: {
                options: [{
                        label: "Test Option Label A",
                        onSelection: spies[0]
                    }, {
                        label: "Test Option Label B",
                        onSelection: spies[1]
                    }, {
                        label: "Test Option Label C",
                        onSelection: spies[2]
                    }, {
                        label: "Test Option Label D",
                        onSelection: spies[3]
                    }]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from any option", function () { return spiesFactory().forEach(function (spy) { return expect(spy).not.toHaveBeenCalled(); }); });
    });
});
describe("number", function () {
    RunIgnoringBackButton("none", 0, function (spies, onBack) { return promptValidator.number(7.6, {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: null,
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
    });
    RunIgnoringBackButton("text", 1, function (spies, onBack) { return promptValidator.number(7.6, {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "text",
            value: {
                minimumLength: 10,
                maximumLength: 25,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from text entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    RunIgnoringBackButton("password", 1, function (spies, onBack) { return promptValidator.number(7.6, {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "password",
            value: {
                minimumLength: 10,
                maximumLength: 25,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from password entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    describe("number", function () {
        RunIgnoringBackButton("valid", 1, function (spies, onBack) {
            spies[0].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.number(7.6, {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "number",
                    value: {
                        minimum: 5.4,
                        maximum: 18.7,
                        step: 0.4,
                        onEntry: spies[0]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("generates one event from number entry", function () { return expect(spiesFactory()[0]).toHaveBeenCalledTimes(1); });
            it("generates the event using the entered number", function () { return expect(spiesFactory()[0])
                .toHaveBeenCalledWith(7.6); });
            it("returns type \"success\" and the event", function () { return expect(resultFactory()).toEqual({
                type: "success",
                event: { eventContent: "Test Event Content" }
            }); });
        });
        RunIgnoringBackButton("invalid step", 1, function (spies, onBack) {
            spies[0].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.number(7.7, {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "number",
                    value: {
                        minimum: 5.4,
                        maximum: 18.7,
                        step: 0.4,
                        onEntry: spies[0]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("returns type \"invalidStep\"", function () { return expect(resultFactory()).toEqual({ type: "invalidStep" }); });
            it("does not generate an event from number entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled; });
        });
        RunIgnoringBackButton("minimum", 1, function (spies, onBack) {
            spies[0].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.number(5.6, {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "number",
                    value: {
                        minimum: 5.6,
                        maximum: 18.4,
                        step: 0.2,
                        onEntry: spies[0]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("generates one event from number entry", function () { return expect(spiesFactory()[0]).toHaveBeenCalledTimes(1); });
            it("generates the event using the entered number", function () { return expect(spiesFactory()[0])
                .toHaveBeenCalledWith(5.6); });
            it("returns type \"success\" and the event", function () { return expect(resultFactory()).toEqual({
                type: "success",
                event: { eventContent: "Test Event Content" }
            }); });
        });
        RunIgnoringBackButton("maximum", 1, function (spies, onBack) {
            spies[0].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.number(18.4, {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "number",
                    value: {
                        minimum: 5.6,
                        maximum: 18.4,
                        step: 0.2,
                        onEntry: spies[0]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("generates one event from number entry", function () { return expect(spiesFactory()[0]).toHaveBeenCalledTimes(1); });
            it("generates the event using the entered number", function () { return expect(spiesFactory()[0])
                .toHaveBeenCalledWith(18.4); });
            it("returns type \"success\" and the event", function () { return expect(resultFactory()).toEqual({
                type: "success",
                event: { eventContent: "Test Event Content" }
            }); });
        });
        RunIgnoringBackButton("less than minimum", 1, function (spies, onBack) {
            spies[0].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.number(5.4, {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "number",
                    value: {
                        minimum: 5.6,
                        maximum: 18.4,
                        step: 0.2,
                        onEntry: spies[0]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("returns type \"lessThanMinimum\"", function () { return expect(resultFactory()).toEqual({ type: "lessThanMinimum" }); });
            it("does not generate an event from number entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled; });
        });
        RunIgnoringBackButton("greater than maximum", 1, function (spies, onBack) {
            spies[0].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.number(18.6, {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "number",
                    value: {
                        minimum: 5.6,
                        maximum: 18.4,
                        step: 0.2,
                        onEntry: spies[0]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("returns type \"greaterThanMaximum\"", function () { return expect(resultFactory()).toEqual({ type: "greaterThanMaximum" }); });
            it("does not generate an event from number entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled; });
        });
        RunIgnoringBackButton("valid negative", 1, function (spies, onBack) {
            spies[0].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.number(-7.6, {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "number",
                    value: {
                        minimum: -18.7,
                        maximum: -5.4,
                        step: 0.4,
                        onEntry: spies[0]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("generates one event from number entry", function () { return expect(spiesFactory()[0]).toHaveBeenCalledTimes(1); });
            it("generates the event using the entered number", function () { return expect(spiesFactory()[0])
                .toHaveBeenCalledWith(-7.6); });
            it("returns type \"success\" and the event", function () { return expect(resultFactory()).toEqual({
                type: "success",
                event: { eventContent: "Test Event Content" }
            }); });
        });
    });
    RunIgnoringBackButton("multiple choice", 4, function (spies, onBack) { return promptValidator.number(7.6, {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "multipleChoice",
            value: {
                options: [{
                        label: "Test Option Label A",
                        onSelection: spies[0]
                    }, {
                        label: "Test Option Label B",
                        onSelection: spies[1]
                    }, {
                        label: "Test Option Label C",
                        onSelection: spies[2]
                    }, {
                        label: "Test Option Label D",
                        onSelection: spies[3]
                    }]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from any option", function () { return spiesFactory().forEach(function (spy) { return expect(spy).not.toHaveBeenCalled(); }); });
    });
});
describe("multipleChoiceByLabel", function () {
    RunIgnoringBackButton("none", 0, function (spies, onBack) { return promptValidator.multipleChoiceByLabel("Test Option Label", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: null,
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
    });
    RunIgnoringBackButton("text", 1, function (spies, onBack) { return promptValidator.multipleChoiceByLabel("Test Option Label", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "text",
            value: {
                minimumLength: 10,
                maximumLength: 25,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from password entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    RunIgnoringBackButton("password", 1, function (spies, onBack) { return promptValidator.multipleChoiceByLabel("Test Option Label", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "password",
            value: {
                minimumLength: 10,
                maximumLength: 25,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from password entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    RunIgnoringBackButton("number", 1, function (spies, onBack) { return promptValidator.multipleChoiceByLabel("Test Option Label", {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "number",
            value: {
                minimum: 5.4,
                maximum: 18.7,
                step: 0.4,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from number entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    describe("multiple choice", function () {
        RunIgnoringBackButton("invalid", 4, function (spies, onBack) { return promptValidator.multipleChoiceByLabel("Test Invalid Option Label", {
            label: "Test Prompt Label",
            description: "Test Prompt Description",
            control: {
                key: "multipleChoice",
                value: {
                    options: [{
                            label: "Test Option Label A",
                            onSelection: spies[0]
                        }, {
                            label: "Test Option Label B",
                            onSelection: spies[1]
                        }, {
                            label: "Test Option Label C",
                            onSelection: spies[2]
                        }, {
                            label: "Test Option Label D",
                            onSelection: spies[3]
                        }]
                }
            },
            onBack: onBack
        }); }, function (spiesFactory, resultFactory) {
            it("returns type \"invalidLabel\"", function () { return expect(resultFactory()).toEqual({ type: "invalidLabel" }); });
            it("does not generate an event from any option", function () { return spiesFactory().forEach(function (spy) { return expect(spy).not.toHaveBeenCalled(); }); });
        });
        RunIgnoringBackButton("valid", 4, function (spies, onBack) {
            spies[2].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.multipleChoiceByLabel("Test Option Label C", {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "multipleChoice",
                    value: {
                        options: [{
                                label: "Test Option Label A",
                                onSelection: spies[0]
                            }, {
                                label: "Test Option Label B",
                                onSelection: spies[1]
                            }, {
                                label: "Test Option Label C",
                                onSelection: spies[2]
                            }, {
                                label: "Test Option Label D",
                                onSelection: spies[3]
                            }]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("generates one event from selected option", function () { return expect(spiesFactory()[2]).toHaveBeenCalledTimes(1); });
            it("does not generate events from the other options", function () {
                expect(spiesFactory()[0]).not.toHaveBeenCalled();
                expect(spiesFactory()[1]).not.toHaveBeenCalled();
                expect(spiesFactory()[3]).not.toHaveBeenCalled();
            });
            it("returns type \"success\" and the event", function () { return expect(resultFactory()).toEqual({
                type: "success",
                event: { eventContent: "Test Event Content" }
            }); });
        });
    });
});
describe("multipleChoiceByIndex", function () {
    RunIgnoringBackButton("none", 0, function (spies, onBack) { return promptValidator.multipleChoiceByIndex(1, {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: null,
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
    });
    RunIgnoringBackButton("text", 1, function (spies, onBack) { return promptValidator.multipleChoiceByIndex(1, {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "text",
            value: {
                minimumLength: 10,
                maximumLength: 25,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from password entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    RunIgnoringBackButton("password", 1, function (spies, onBack) { return promptValidator.multipleChoiceByIndex(1, {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "password",
            value: {
                minimumLength: 10,
                maximumLength: 25,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from password entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    RunIgnoringBackButton("number", 1, function (spies, onBack) { return promptValidator.multipleChoiceByIndex(1, {
        label: "Test Prompt Label",
        description: "Test Prompt Description",
        control: {
            key: "number",
            value: {
                minimum: 5.4,
                maximum: 18.7,
                step: 0.4,
                onEntry: spies[0]
            }
        },
        onBack: onBack
    }); }, function (spiesFactory, resultFactory) {
        it("returns type \"invalidControl\"", function () { return expect(resultFactory()).toEqual({ type: "invalidControl" }); });
        it("does not generate an event from number entry", function () { return expect(spiesFactory()[0]).not.toHaveBeenCalled(); });
    });
    describe("multiple choice", function () {
        RunIgnoringBackButton("out of range", 4, function (spies, onBack) { return promptValidator.multipleChoiceByIndex(4, {
            label: "Test Prompt Label",
            description: "Test Prompt Description",
            control: {
                key: "multipleChoice",
                value: {
                    options: [{
                            label: "Test Option Label A",
                            onSelection: spies[0]
                        }, {
                            label: "Test Option Label B",
                            onSelection: spies[1]
                        }, {
                            label: "Test Option Label C",
                            onSelection: spies[2]
                        }, {
                            label: "Test Option Label D",
                            onSelection: spies[3]
                        }]
                }
            },
            onBack: onBack
        }); }, function (spiesFactory, resultFactory) {
            it("returns type \"indexOutOfRange\"", function () { return expect(resultFactory()).toEqual({ type: "indexOutOfRange" }); });
            it("does not generate an event from any option", function () { return spiesFactory().forEach(function (spy) { return expect(spy).not.toHaveBeenCalled(); }); });
        });
        RunIgnoringBackButton("further out of range", 4, function (spies, onBack) { return promptValidator.multipleChoiceByIndex(5, {
            label: "Test Prompt Label",
            description: "Test Prompt Description",
            control: {
                key: "multipleChoice",
                value: {
                    options: [{
                            label: "Test Option Label A",
                            onSelection: spies[0]
                        }, {
                            label: "Test Option Label B",
                            onSelection: spies[1]
                        }, {
                            label: "Test Option Label C",
                            onSelection: spies[2]
                        }, {
                            label: "Test Option Label D",
                            onSelection: spies[3]
                        }]
                }
            },
            onBack: onBack
        }); }, function (spiesFactory, resultFactory) {
            it("returns type \"indexOutOfRange\"", function () { return expect(resultFactory()).toEqual({ type: "indexOutOfRange" }); });
            it("does not generate an event from any option", function () { return spiesFactory().forEach(function (spy) { return expect(spy).not.toHaveBeenCalled(); }); });
        });
        RunIgnoringBackButton("valid", 4, function (spies, onBack) {
            spies[1].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.multipleChoiceByIndex(1, {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "multipleChoice",
                    value: {
                        options: [{
                                label: "Test Option Label A",
                                onSelection: spies[0]
                            }, {
                                label: "Test Option Label B",
                                onSelection: spies[1]
                            }, {
                                label: "Test Option Label C",
                                onSelection: spies[2]
                            }, {
                                label: "Test Option Label D",
                                onSelection: spies[3]
                            }]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("generates one event from selected option", function () { return expect(spiesFactory()[1]).toHaveBeenCalledTimes(1); });
            it("does not generate events from the other options", function () {
                expect(spiesFactory()[0]).not.toHaveBeenCalled();
                expect(spiesFactory()[2]).not.toHaveBeenCalled();
                expect(spiesFactory()[3]).not.toHaveBeenCalled();
            });
            it("returns type \"success\" and the event", function () { return expect(resultFactory()).toEqual({
                type: "success",
                event: { eventContent: "Test Event Content" }
            }); });
        });
        RunIgnoringBackButton("valid last", 4, function (spies, onBack) {
            spies[3].and.returnValue({ eventContent: "Test Event Content" });
            return promptValidator.multipleChoiceByIndex(3, {
                label: "Test Prompt Label",
                description: "Test Prompt Description",
                control: {
                    key: "multipleChoice",
                    value: {
                        options: [{
                                label: "Test Option Label A",
                                onSelection: spies[0]
                            }, {
                                label: "Test Option Label B",
                                onSelection: spies[1]
                            }, {
                                label: "Test Option Label C",
                                onSelection: spies[2]
                            }, {
                                label: "Test Option Label D",
                                onSelection: spies[3]
                            }]
                    }
                },
                onBack: onBack
            });
        }, function (spiesFactory, resultFactory) {
            it("generates one event from selected option", function () { return expect(spiesFactory()[3]).toHaveBeenCalledTimes(1); });
            it("does not generate events from the other options", function () {
                expect(spiesFactory()[0]).not.toHaveBeenCalled();
                expect(spiesFactory()[1]).not.toHaveBeenCalled();
                expect(spiesFactory()[2]).not.toHaveBeenCalled();
            });
            it("returns type \"success\" and the event", function () { return expect(resultFactory()).toEqual({
                type: "success",
                event: { eventContent: "Test Event Content" }
            }); });
        });
    });
});
function RunIgnoringBackButton(description, numberOfSpies, act, assert) {
    describe(description, function () {
        var spies;
        beforeEach(function () {
            spies = [];
            while (spies.length < numberOfSpies) {
                spies.push(jasmine.createSpy());
            }
        });
        var result;
        describe("without a back button", function () {
            beforeEach(function () { return result = act(spies, null); });
            assert(function () { return spies; }, function () { return result; });
        });
        describe("with a back button", function () {
            var onBack;
            beforeEach(function () {
                onBack = jasmine.createSpy();
                result = act(spies, onBack);
            });
            assert(function () { return spies; }, function () { return result; });
            it("does not generate an event from the back button", function () { return expect(onBack).not.toHaveBeenCalled(); });
        });
    });
}
//# sourceMappingURL=PromptValidator.Tests.js.map