"use strict";
exports.__esModule = true;
/**
 * @inheritdoc
 */
var PromptValidator = /** @class */ (function () {
    function PromptValidator() {
    }
    /**
     * @inheritdoc
     */
    PromptValidator.prototype.back = function (prompt) {
        if (!prompt.onBack) {
            return { type: "invalidControl" };
        }
        return {
            type: "success",
            event: prompt.onBack()
        };
    };
    /**
     * @inheritdoc
     */
    PromptValidator.prototype.text = function (text, prompt) {
        if (!prompt.control || prompt.control.key != "text") {
            return { type: "invalidControl" };
        }
        text = text
            .toLowerCase()
            .trim()
            .replace(/\s+/g, " ");
        if (text.length < prompt.control.value.minimumLength) {
            return { type: "tooShort" };
        }
        if (text.length > prompt.control.value.maximumLength) {
            return { type: "tooLong" };
        }
        return {
            type: "success",
            event: prompt.control.value.onEntry(text)
        };
    };
    /**
     * @inheritdoc
     */
    PromptValidator.prototype.password = function (password, prompt) {
        if (!prompt.control || prompt.control.key != "password") {
            return { type: "invalidControl" };
        }
        password = password.trim();
        if (password.length < prompt.control.value.minimumLength) {
            return { type: "tooShort" };
        }
        if (password.length > prompt.control.value.maximumLength) {
            return { type: "tooLong" };
        }
        return {
            type: "success",
            event: prompt.control.value.onEntry(password)
        };
    };
    /**
     * @inheritdoc
     */
    PromptValidator.prototype.number = function (number, prompt) {
        if (!prompt.control || prompt.control.key != "number") {
            return { type: "invalidControl" };
        }
        if (number < prompt.control.value.minimum) {
            return { type: "lessThanMinimum" };
        }
        if (number > prompt.control.value.maximum) {
            return { type: "greaterThanMaximum" };
        }
        var rounded = number % prompt.control.value.step;
        var tolerance = 0.00001;
        if (rounded > tolerance && rounded < prompt.control.value.step - tolerance) {
            return { type: "invalidStep" };
        }
        return {
            type: "success",
            event: prompt.control.value.onEntry(number)
        };
    };
    /**
     * @inheritdoc
     */
    PromptValidator.prototype.multipleChoiceByLabel = function (label, prompt) {
        if (!prompt.control || prompt.control.key != "multipleChoice") {
            return { type: "invalidControl" };
        }
        for (var _i = 0, _a = prompt.control.value.options; _i < _a.length; _i++) {
            var option = _a[_i];
            if (option.label == label) {
                return {
                    type: "success",
                    event: option.onSelection()
                };
            }
        }
        return { type: "invalidLabel" };
    };
    /**
     * @inheritdoc
     */
    PromptValidator.prototype.multipleChoiceByIndex = function (index, prompt) {
        if (!prompt.control || prompt.control.key != "multipleChoice") {
            return { type: "invalidControl" };
        }
        if (index >= prompt.control.value.options.length) {
            return { type: "indexOutOfRange" };
        }
        return {
            type: "success",
            event: prompt.control.value.options[index].onSelection()
        };
    };
    return PromptValidator;
}());
exports["default"] = PromptValidator;
//# sourceMappingURL=PromptValidator.js.map